fallintoplace opened a new pull request, #2116: URL: https://github.com/apache/iceberg-go/pull/2116
**What** - Append common partition values directly to Arrow builders. **Why** - Avoid scalar creation and dispatch for each value in metadata scans. **Implementation** - Bind primitive append functions once and retain the scalar fallback for other values. - With 32 fields and 4,096 files, median time fell from 17.70 ms to 4.39 ms; allocations fell from 387,042 to 1,521 per operation. -- This is an automated message from the Apache Git Service. To respond to the message, please log on to GitHub and use the URL above to go to the specific comment. To unsubscribe, e-mail: [email protected] For queries about this service, please contact Infrastructure at: [email protected] --------------------------------------------------------------------- To unsubscribe, e-mail: [email protected] For additional commands, e-mail: [email protected]
